# MCP Auth Python SDK

[![GitHub branch check runs](https://img.shields.io/github/check-runs/mcp-auth/python/master)](https://github.com/mcp-auth/python/actions?query=branch%3Amaster)
[![codecov](https://codecov.io/gh/mcp-auth/python/graph/badge.svg?token=JXZ4C50SCV)](https://codecov.io/gh/mcp-auth/python)
[![Stable Version](https://img.shields.io/pypi/v/mcpauth?label=stable)][PyPI Releases]
[![Required Python Version](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fmcp-auth%2Fpython%2Fmaster%2Fpyproject.toml)][PyPI]
[![PyPI - License](https://img.shields.io/pypi/l/mcpauth)](https://github.com/mcp-auth/python/blob/master/LICENSE)

[Website]: https://mcp-auth.dev/
[PyPI]: https://pypi.org/project/mcpauth/
[PyPI Releases]: https://pypi.org/project/mcpauth/#history

The MCP spec [requires OAuth 2.1 and other RFCs](https://modelcontextprotocol.io/specification/2025-03-26/basic/authorization) for auth. Instead of spending weeks on them, use MCP Auth to connect to an trusted provider with a few lines of code.

## Get started

### Is my provider supported?

Check out the [MCP-compatible providers](https://mcp-auth.dev/docs/provider-list) to see which providers are supported. It also includes a tool for real-time checking of provider compatibility.

### Installation

```bash
pip install mcpauth
```

Or use your package manager of choice, such as `poetry` or `uv`.

See [the documentation](https://mcp-auth.dev/docs) for the full guide.

## Join the discussion

Join the [MCP Auth org discussion](https://github.com/orgs/mcp-auth/discussions) to ask questions or share your feedback.
